import fastapi
from starlette import status

from core.ctrl import BaseController

from exceptions import common as common_exc, http as http_exc
from db.repositories.movie import MovieRepository
from .services import MovieService


class MovieController(BaseController):
    repo = MovieRepository()
    movie_service = MovieService()

    async def get_list(self, **kwargs):
        return await self.movie_service.get_list_movie(**kwargs)

    async def get(self, id: int):
        try:
            return await self.movie_service.get_movie(id)

        except common_exc.NotFoundException as e:
            raise http_exc.HTTPNotFoundException(detail=str(e))

    async def create(self, **kwargs):
        try:
            return await self.movie_service.create_movie(**kwargs)

        except common_exc.CreateException as e:
            raise http_exc.HTTPBadRequestException(detail=str(e))

        except common_exc.NotFoundException:
            raise http_exc.HTTPBadRequestException(detail="Director and genre are required for creating a movie.")

    async def update(self, id: int, **kwargs):
        try:
            return await self.movie_service.update_movie(id, **kwargs)

        except common_exc.UpdateException as e:
            raise http_exc.HTTPBadRequestException(detail=str(e))

        except common_exc.NotFoundException as e:
            raise http_exc.HTTPNotFoundException(detail=str(e))

    async def delete(self, id: int):
        try:
            await self.movie_service.delete_movie(id)
            return fastapi.responses.Response(status_code=status.HTTP_204_NO_CONTENT)

        except common_exc.DeleteException as e:
            raise http_exc.HTTPBadRequestException(detail=str(e))

        except common_exc.NotFoundException as e:
            raise http_exc.HTTPNotFoundException(detail=str(e))
