import fastapi

from .schemas import (
    MovieBaseSchema, MovieListSchema,
    MoviePostSchema, MoviePatchSchema
)
from .ctrl import MovieController


router = fastapi.APIRouter(prefix='/movies', tags=['Movie'])
ctrl = MovieController()


@router.get('')
async def get_movies(query: MovieBaseSchema = fastapi.Depends()):
    movies = await ctrl.get_list(**query.model_dump(exclude_none=True))
    return [MovieListSchema.from_orm(movie) for movie in movies]


@router.get('/{id}')
async def get_movie(id: int):
    return await ctrl.get(id)


@router.post('')
async def create_movie(body: MoviePostSchema):
    return await ctrl.create(**body.model_dump(exclude_none=True))


@router.patch('/{id}')
async def update_movie(id: int, body: MoviePatchSchema):
    return await ctrl.update(id, **body.model_dump(exclude_none=True))


@router.delete('/{id}')
async def delete_movie(id: int):
    return await ctrl.delete(id)
